#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagged
version: 0.8.4
id: tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
key: tagge_LPeicl3HxVfGUMMwMEsAE6
license: BSD3
copyright: 2009-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/tagged
synopsis: Haskell 98 phantom types to avoid unsafely passing dummy arguments
description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments
category: Data, Phantom Types
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Tagged Data.Proxy.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/tagged-0.8.4
hs-libraries: HStagged-0.8.4-LPeicl3HxVfGUMMwMEsAE6
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html: /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
